``starcat`` Module
==================

.. automodule:: starcat
    :member-order: bysource
    :members:
    :undoc-members:
    :special-members:
    :show-inheritance:
    :exclude-members: __dict__, __hash__, __module__, __weakref__, __enter__, __exit__, __annotations__

.. .. automodule:: starcat.spice
..     :member-order: bysource
..     :members:
..     :undoc-members:
..     :special-members:
..     :show-inheritance:
..     :exclude-members: __dict__, __hash__, __module__, __weakref__, __enter__, __exit__, __annotations__

.. .. automodule:: starcat.ucac4
..     :member-order: bysource
..     :members:
..     :undoc-members:
..     :special-members:
..     :show-inheritance:
..     :exclude-members: __dict__, __hash__, __module__, __weakref__, __enter__, __exit__, __annotations__

.. .. automodule:: starcat.ybsc
..     :member-order: bysource
..     :members:
..     :undoc-members:
..     :special-members:
..     :show-inheritance:
..     :exclude-members: __dict__, __hash__, __module__, __weakref__, __enter__, __exit__, __annotations__
